@@ -25,7 +25,13 @@ class Tk::BWidget::PanedWindow
 
   def get_frame(idx, &b)
     win = window(tk_send_without_enc('getframe', idx))
-    win.instance_eval(&b) if b
+    if b
+      if TkCore::WITH_RUBY_VM  ### Ruby 1.9 !!!!
+        win.instance_exec(self, &b)
+      else
+        win.instance_eval(&b)
+      end
+    end
     win
   end
 end
