@@ -23,7 +23,13 @@ class Tk::BWidget::ScrollableFrame
 
   def get_frame(&b)
     win = window(tk_send_without_enc('getframe'))
-    win.instance_eval(&b) if b
+    if b
+      if TkCore::WITH_RUBY_VM  ### Ruby 1.9 !!!!
+        win.instance_exec(self, &b)
+      else
+        win.instance_eval(&b)
+      end
+    end
     win
   end
 
